LocationUpdateEvent class

A location point forwarded from the native SDK's GPS pipeline.

Constructors

LocationUpdateEvent({required double latitude, required double longitude, double altitude = 0.0, double accuracy = 0.0, double speed = 0.0, double heading = 0.0, required int timestamp})
const
LocationUpdateEvent.fromMap(Map<Object?, Object?> map)
factory

Properties

accuracy double
final
altitude double
final
dateTime DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
heading double
final
latitude double
final
longitude double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
final
timestamp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited