TrackingStatusEvent class

A status notification from the SDK, emitted when tracking starts/stops, when a permission changes, or when an error occurs.

Constructors

TrackingStatusEvent({required bool isTracking, String status = 'unknown', String? message, required int timestamp})
const
TrackingStatusEvent.fromMap(Map<Object?, Object?> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isTracking bool
final
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
timestamp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited