VehicleType class abstract final

Integer constants that match the VMVehicleType enum in the native SDK.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bike → const int
bus → const int
car → const int
coach → const int
cycle → const int
pedestrian → const int
semiTrailer → const int
taxi → const int
trailer → const int
truck → const int