FakeGpsPolicy class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

logToServer → const String
Save the location to the DB with is_fake=1 and upload with header X-Fake-GPS: true. Native deduplicates: only writes if >60s or >5m from the previous fake record.
skip → const String
Detect fake GPS, but do not warn/stop/upload. Default.
stopTracking → const String
Stop tracking immediately when fake GPS is first detected.
values → const List<String>
warn → const String
Display a local notification warning the user (debounced 30s by native).